<h3 align="center">
  <a name="readme-top"></a>
  <img
    src="https://docs.arcade.dev/images/logo/arcade-logo.png"
  >
</h3>
<div align="center">
  <h3>CrewAI Integration</h3>
    <a href="https://github.com/arcadeai/arcade-ai/blob/main/LICENSE">
  <img src="https://img.shields.io/badge/License-MIT-yellow.svg" alt="License">
</a>
    <a href="https://pepy.tech/project/crewai-arcade">
  <img src="https://static.pepy.tech/badge/crewai-arcade" alt="Downloads">
</a>

</div>

<p align="center">
    <a href="https://docs.arcade.dev" target="_blank">Docs</a> •
    <a href="https://docs.arcade.dev/toolkits" target="_blank">Toolkits</a> •
    <a href="https://github.com/ArcadeAI/cookbook" target="_blank">Cookbook</a> •
    <a href="https://github.com/ArcadeAI/arcade-py" target="_blank">Python Client</a> •
    <a href="https://github.com/ArcadeAI/arcade-js" target="_blank">JavaScript Client</a>
</p>

## Overview

`crewai-arcade` allows you to use Arcade tools in your CrewAI applications.

## Installation

```bash
pip install crewai-arcade
```

## Usage

See the [examples](https://github.com/ArcadeAI/arcade-ai/tree/main/examples/crewai) for usage examples
